;;; nael-skeleton.el --- Skeleton for Nael  -*- lexical-binding: t; -*-

;; Copyright © 2026 Mekeor Melire

;; SPDX-License-Identifier: GPL-3.0-only

;; This is licensed under GNU General Public License (version 3 only),
;; see LICENSE.GPL3.

;;; Commentary:

;; This file has been generated by `build.el' by relying on data from
;; the official Lean plugin for another editor.  Please do not edit
;; this file directly; edit `build.el' instead!

;; This file defines Skeleton templates for abbreviations that expand
;; to two strings, with point being placed between the left and the
;; right part.  For more information on Emacs' built-in `skeleton'
;; package, see consult its Info manual:
;;
;;   (info "(autotype) Top")

;; Note that `nael-abbrev' defines Abbrev tables built on top of these
;; Skeleton templates, as described at:
;;
;;   (info "(autotype) Skeletons as Abbrevs")

;;; Code:

(require 'skeleton)

(define-skeleton nael-skeleton-7b7d "" nil "{" _ "}")
(define-skeleton nael-skeleton-7b7d5f "" nil "{" _ "}_")
(define-skeleton nael-skeleton-7b7b7d7d "" nil "⦃" _ "⦄")
(define-skeleton nael-skeleton-5b5d "" nil "[" _ "]")
(define-skeleton nael-skeleton-5b5d5f "" nil "[" _ "]_")
(define-skeleton nael-skeleton-5b5b5d5d "" nil "⟦" _ "⟧")
(define-skeleton nael-skeleton-3c3e "" nil "⟨" _ "⟩")
(define-skeleton nael-skeleton-2829 "" nil "(" _ ")")
(define-skeleton nael-skeleton-28295f "" nil "(" _ ")_")
(define-skeleton nael-skeleton-285b5d2927 "" nil "⟮" _ "⟯")
(define-skeleton nael-skeleton-28282929 "" nil "⸨" _ "⸩")
(define-skeleton nael-skeleton-663c3e "" nil "‹" _ "›")
(define-skeleton nael-skeleton-663c3c3e3e "" nil "«" _ "»")
(define-skeleton nael-skeleton-5b2d2d5d "" nil "⁅" _ "⁆")
(define-skeleton nael-skeleton-7c7c7c7c "" nil "‖" _ "‖")
(define-skeleton nael-skeleton-6e6e6e6f726d "" nil "‖" _ "‖₊")
(define-skeleton nael-skeleton-6e6f726d "" nil "‖" _ "‖")
(define-skeleton nael-skeleton-666c6f6f72 "" nil "⌊" _ "⌋")
(define-skeleton nael-skeleton-6365696c "" nil "⌈" _ "⌉")
(define-skeleton nael-skeleton-6e666c6f6f72 "" nil "⌊" _ "⌋₊")
(define-skeleton nael-skeleton-6e6365696c "" nil "⌈" _ "⌉₊")
(define-skeleton nael-skeleton-735b5d "" nil "⦋" _ "⦌")
(define-skeleton nael-skeleton-73696d706c6578 "" nil "⦋" _ "⦌")

(provide 'nael-skeleton)

;;; nael-skeleton.el ends here

;; Local Variables:
;; buffer-read-only: t
;; End:
